//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package date

import (
	"reflect"
	"testing"
	"time"
	_ "time/tzdata"
)

func TestGetDateFromWeekNumber(t *testing.T) {
	europeTime, _ := time.LoadLocation("Europe/Berlin")

	type args struct {
		year       int
		weekNumber int
		dayName    string
	}
	tests := []struct {
		name    string
		args    args
		want    time.Time
		wantErr bool
	}{
		{
			name: "Test 1",
			args: args{
				year:       2021,
				weekNumber: 1,
				dayName:    "Montag",
			},
			want:    time.Date(2021, 1, 4, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
		{
			name: "Test 2",
			args: args{
				year:       2023,
				weekNumber: 57,
				dayName:    "Montag",
			},
			want:    time.Date(2024, 1, 29, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
		{
			name: "Test 3",
			args: args{
				year:       2023,
				weekNumber: 1,
				dayName:    "Montag",
			},
			want:    time.Date(2023, 1, 2, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			got, err := GetDateFromWeekNumber(tt.args.year, tt.args.weekNumber, tt.args.dayName)
			if (err != nil) != tt.wantErr {
				t.Errorf("getDateFromWeekNumber() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !reflect.DeepEqual(got, tt.want) {
				t.Errorf("getDateFromWeekNumber() got = %v, want %v", got, tt.want)
			}
		})
	}
}
