//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package v1

import (
	"htwkalender/data-manager/model"
	"testing"
)

func TestContains(t *testing.T) {
	type args struct {
		groups []model.SeminarGroup
		group  model.SeminarGroup
	}
	tests := []struct {
		name string
		args args
		want bool
	}{
		{
			name: "should return true if group is in groups",
			args: args{
				groups: []model.SeminarGroup{
					{
						Course:   "test",
						Semester: "test",
					},
				},
				group: model.SeminarGroup{
					Course:   "test",
					Semester: "test",
				},
			},
			want: true,
		},
		{
			name: "should return false if group is not in groups",
			args: args{
				groups: []model.SeminarGroup{
					{
						Course:   "test",
						Semester: "test",
					},
				},
				group: model.SeminarGroup{
					Course:   "test",
					Semester: "test2",
				},
			},
			want: false,
		},
		{
			name: "should return false if group is not in courses",
			args: args{
				groups: []model.SeminarGroup{
					{
						Course:   "test3",
						Semester: "test",
					},
				},
				group: model.SeminarGroup{
					Course:   "test",
					Semester: "test",
				},
			},
			want: false,
		},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if got := contains(tt.args.groups, tt.args.group); got != tt.want {
				t.Errorf("contains() = %v, want %v", got, tt.want)
			}
		})
	}
}
