//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package names

import (
	"htwkalender/data-manager/model"
	"testing"
)

func TestReplaceTemplateSubStrings(t *testing.T) {
	type args struct {
		rawString string
		event     model.Event
	}
	tests := []struct {
		name string
		args args
		want string
	}{
		{
			name: "Test 1",
			args: args{
				rawString: "%t",
				event: model.Event{
					EventType: "Test",
				},
			},
			want: "Test",
		},
		{
			name: "Test 2",
			args: args{
				rawString: "%p",
				event: model.Event{
					Compulsory: "Test",
				},
			},
			want: "Test",
		},
		{
			name: "Test 3",
			args: args{
				rawString: "%%",
				event: model.Event{
					EventType: "Test",
				},
			},
			want: "%",
		},
		{
			name: "Test 4",
			args: args{
				rawString: "%t %p",
				event: model.Event{
					EventType:  "Test",
					Compulsory: "Test",
				},
			},
			want: "Test Test",
		},
		{
			name: "Test 5",
			args: args{
				rawString: "%t %p %%",
				event: model.Event{
					EventType:  "Test",
					Compulsory: "Test",
				},
			},
			want: "Test Test %",
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if got := ReplaceTemplateSubStrings(tt.args.rawString, tt.args.event); got != tt.want {
				t.Errorf("ReplaceTemplateSubStrings() = %v, want %v", got, tt.want)
			}
		})
	}
}
