//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package grpc

import (
	"google.golang.org/grpc"
	"google.golang.org/grpc/credentials/insecure"
	"google.golang.org/grpc/keepalive"
	"log/slog"
	"sync"
	"time"
)

var conn *grpc.ClientConn
var once sync.Once

func ConnectGRPCServer(host string) *grpc.ClientConn {
	once.Do(func() {
		var err error
		conn, err = grpc.NewClient(
			host+":50051",
			grpc.WithTransportCredentials(insecure.NewCredentials()),
			grpc.WithKeepaliveParams(keepalive.ClientParameters{
				Time:                2 * time.Minute,
				Timeout:             20 * time.Second,
				PermitWithoutStream: true,
			}),
		)
		if err != nil {
			slog.Error("could not connect to grpc server", "error", err)
		}
	})
	return conn
}

func CloseGRPCServer(conn *grpc.ClientConn) {
	err := conn.Close()
	if err != nil {
		slog.Error("could not close connection", "error", err)
	}
}
