//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package grpc

import (
	"context"
	"google.golang.org/grpc"
	pb "htwkalender/common/genproto/modules"
	"htwkalender/ical/model"
	"log/slog"
	"time"
)

func GetEventsByModules(modules []model.FeedModule, conn *grpc.ClientConn) (model.Events, error) {
	c := pb.NewModuleServiceClient(conn)
	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	defer cancel()

	// List of uuids
	uuids := make([]string, 0)
	for _, module := range modules {
		uuids = append(uuids, module.UUID)
	}

	r, err := c.GetEventsForModules(ctx, &pb.GetModulesRequest{Uuids: uuids})
	if err != nil {
		slog.Error("could not get modules: %v", "error", err)
	}

	events := make(model.Events, 0)
	for _, event := range r.GetEvents() {
		events = append(events, protoToEvent(event))
	}

	return events, nil
}

func GetEventsByRoom(room string, conn *grpc.ClientConn) (model.Events, error) {
	c := pb.NewRoomServiceClient(conn)
	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	defer cancel()

	r, err := c.GetRoomEvents(ctx, &pb.GetRoomRequest{Room: room})
	if err != nil {
		slog.Error("could not get room events: ", "error", err)
	}

	events := make(model.Events, 0)
	for _, event := range r.GetEvents() {
		events = append(events, protoToEvent(event))
	}

	return events, nil
}
