//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package grpc

import (
	"context"
	"github.com/goccy/go-json"
	"google.golang.org/grpc"
	pb "htwkalender/common/genproto/modules"
	"htwkalender/ical/model"
	"log/slog"
	"time"
)

func GetFeed(feedId string, conn *grpc.ClientConn) (model.FeedRecord, error) {
	c := pb.NewFeedServiceClient(conn)
	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	defer cancel()

	r, err := c.GetFeed(ctx, &pb.GetFeedRequest{Id: feedId})
	if err != nil {
		slog.Error("could not get modules: %v", "error", err)
		return model.FeedRecord{}, err
	}

	feed, err := protoToFeed(r.GetFeed())
	if err != nil {
		slog.Error("could not convert feed: %v", "error", err)
		return model.FeedRecord{}, err
	}

	return feed, nil
}

func protoToFeed(feed *pb.Feed) (model.FeedRecord, error) {

	// unmarshal the []model.FeedModule from json
	var modules []model.FeedModule
	err := json.Unmarshal([]byte(feed.Modules), &modules)
	if err != nil {
		slog.Error("could not unmarshal modules: %v", "error", err)
		return model.FeedRecord{}, err
	}

	return model.FeedRecord{
		BaseModel: model.BaseModel{
			Id:      feed.Id,
			Created: model.ToJSONTime(feed.Created),
			Updated: model.ToJSONTime(feed.Updated),
		},
		Retrieved: model.ToJSONTime(feed.Retrieved),
		Modules:   modules,
		Deleted:   feed.Deleted,
	}, nil
}
