//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package connector

import (
	"github.com/gofiber/fiber/v3/client"
	"htwkalender/ical/model"
	"time"
)

func RequestApi(host string, path string) (*client.Response, error) {

	cc := client.New()
	cc.SetTimeout(5 * time.Second)

	// set retry to 0
	response, err := cc.Get(host + path)
	if err != nil {
		return nil, err
	}

	return response, nil
}

func DeleteRequestApi(host string, path string) error {

	cc := client.New()
	cc.SetTimeout(5 * time.Second)

	// set retry to 0
	_, err := cc.Delete(host + path)
	if err != nil {
		return err
	}

	return nil
}

func PostRequestApi(host string, path string, body []model.FeedCollection) (*client.Response, error) {

	cc := client.New()
	cc.SetTimeout(5 * time.Second)

	config := client.Config{
		Body: body,
		Header: map[string]string{
			"Content-Type": "application/json",
			"Accept":       "*/*",
		},
	}

	// set retry to 0
	response, err := cc.Post(host+path, config)
	if err != nil {
		return nil, err
	}

	return response, nil
}
