//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package functions

import (
	localTime "htwkalender/ical/service/functions/time"
	"time"
)

// GetCurrentSemesterString returns the current semester as string
// if current month is between 10 and 03 -> winter semester "ws"
func GetCurrentSemesterString(localeTime localTime.Clock) string {
	if localeTime.Now().Month() >= 10 || localeTime.Now().Month() <= 3 {
		return "ws"
	} else {
		return "ss"
	}
}

func CalculateSemesterList(clock localTime.Clock) []string {
	summerSemester := clock.Now().Month() >= time.March && clock.Now().Month() <= time.September
	winterSemester := clock.Now().Month() <= time.March || clock.Now().Month() >= time.September

	if summerSemester && !winterSemester {
		return []string{"ss"}
	}

	if !summerSemester && winterSemester {
		return []string{"ws"}
	}

	return []string{"ss", "ws"}
}
