//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

package functions

import (
	mockTime "htwkalender/ical/service/functions/time"
	"reflect"
	"testing"
	"time"
)

func TestCalculateSemesterList(t *testing.T) {
	type args struct {
		clock mockTime.Clock
	}
	tests := []struct {
		name string
		args args
		want []string
	}{
		{
			name: "is summer semester",
			args: args{
				clock: mockTime.MockClock{
					NowTime: time.Date(2024, 6, 1, 0, 0, 0, 0, time.UTC),
				},
			},
			want: []string{"ss"},
		},
		{
			name: "is winter semester",
			args: args{
				clock: mockTime.MockClock{
					NowTime: time.Date(2024, 1, 1, 0, 0, 0, 0, time.UTC),
				},
			},
			want: []string{"ws"},
		},
		{
			name: "is in both",
			args: args{
				clock: mockTime.MockClock{
					NowTime: time.Date(2024, 3, 22, 0, 0, 0, 0, time.UTC),
				},
			},
			want: []string{"ss", "ws"},
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if got := CalculateSemesterList(tt.args.clock); !reflect.DeepEqual(got, tt.want) {
				t.Errorf("calculateSemesterList() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestGetCurrentSemesterString(t *testing.T) {
	type args struct {
		localeTime mockTime.Clock
	}
	tests := []struct {
		name string
		args args
		want string
	}{
		{
			name: "is winter semester",
			args: args{
				localeTime: mockTime.MockClock{
					NowTime: time.Date(2024, 1, 1, 0, 0, 0, 0, time.UTC),
				},
			},
			want: "ws",
		},
		{
			name: "is summer semester",
			args: args{
				localeTime: mockTime.MockClock{
					NowTime: time.Date(2024, 6, 1, 0, 0, 0, 0, time.UTC),
				},
			},
			want: "ss",
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if got := GetCurrentSemesterString(tt.args.localeTime); got != tt.want {
				t.Errorf("GetCurrentSemesterString() = %v, want %v", got, tt.want)
			}
		})
	}
}
